@@ -92,7 +92,7 @@ fi
 echo
 echo "running "${BLD_ON}"automake"${BLD_OFF}
 echo "----------------------------------------------------"
-automake -a -c
+automake -a -c -f
 if [ $? -ne 0 ]; then
     exit 1
 fi
