@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2007 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -39,6 +39,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 enum {
   CHANGED,
   MOVE_CURSOR,
+  SELECTION,
   LAST_SIGNAL
 };
 
@@ -782,6 +783,20 @@ on_hex_text_key_press_event        (GtkWidget       *widget,
   hex = GTK_HEX(user_data);
   ed = GTK_EDITABLE(widget);
 
+  /* If the user pressed Ctrl-C, copy the packet content as we
+   * rendered it into the clipboard.
+   */
+  if ((event->state & GDK_CONTROL_MASK) != 0 &&
+      event->keyval == GDK_c)
+    {
+      gchar *content = gtk_editable_get_chars(GTK_EDITABLE(hex->hex_text), 0, -1);
+      gtk_signal_emit(GTK_OBJECT(hex), hex_signals[SELECTION],
+		      content);
+      g_free(content);
+      gtk_signal_emit_stop_by_name(GTK_OBJECT(widget), "key_press_event");
+      return TRUE;
+    }
+      
   if (hex->mode != GTK_RAW_HEX)
     return FALSE;
 
@@ -1308,6 +1323,15 @@ gtk_hex_class_init (GtkHexClass *class)
 		    GTK_TYPE_NONE, 1, 
 		    GTK_TYPE_INT);
 
+  hex_signals[SELECTION] =
+    gtk_signal_new ("selection",
+		    GTK_RUN_LAST | GTK_RUN_ACTION,
+		    object_class->type,
+		    GTK_SIGNAL_OFFSET (GtkHexClass, selection),
+		    gtk_marshal_NONE__STRING,
+		    GTK_TYPE_NONE, 1,
+		    GTK_TYPE_STRING);
+
   gtk_object_class_add_signals(object_class, hex_signals, LAST_SIGNAL);
 
   object_class->destroy = gtk_hex_destroy;
