@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2007 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -419,4 +419,14 @@ nd_clipboard_occupied(void)
   return (cb != NULL);
 }
 
-
+void
+nd_clipboard_set_content(const char *content)
+{
+  g_free(cb_content_string);
+  cb_content_string = g_strdup(content);
+  
+  /* Make sure that we now own the selection */
+  gtk_selection_owner_set(nd_toplevel_window,
+			  GDK_SELECTION_PRIMARY,
+			  GDK_CURRENT_TIME);
+}
