@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -25,14 +25,20 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __nd_globals_h
 #define __nd_globals_h
 
-#include <gtk/gtk.h>
+#include <nd.h>
 
-/* Let's make some useful goodies available everywhere: */
+typedef struct nd_runtime_options
+{
+  /* When TRUE, list all registered plugins, then exit: */
+  gboolean     show_plugins;
+  gboolean     use_fam;
+  gboolean     debug;
+
+} ND_RuntimeOptions;
+
+extern ND_RuntimeOptions nd_runtime_options;
 
 /* The toplevel main window of the application */
-extern GtkWidget   *toplevel;
-
-/* A global error buffer for use with pcap */
-extern char         pcap_errbuf[];
+extern GtkWidget        *nd_toplevel_window;
 
 #endif
