@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2007 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -1122,7 +1122,7 @@ gui_list_update_packet(const LND_Packet *packet, char *line, int len)
     {
       char magicstr[512];
       guchar *raw_start2 = NULL;
-      guchar *sep = strstr(raw_start, "\r\n\r\n");
+      guchar *sep = (guchar*) strstr((const char*) raw_start, "\r\n\r\n");
       
       if (sep && sep + 4 != raw_end)
 	{
