@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -26,8 +26,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __nd_gui_h
 
 #include <gtk/gtk.h>
-#include <netdude/nd_packet.h>
-#include <netdude/nd_trace.h>
+#include <nd_packet.h>
+#include <nd_trace.h>
 
 /**
  * ND_MenuEntryCB - callback signature used for protocol menu entries.
@@ -42,7 +42,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  * edited when the menu was popped up (including the correct nesting
  * level).
  */
-typedef void (*ND_MenuEntryCB) (ND_Packet   *packet,
+typedef void (*ND_MenuEntryCB) (LND_Packet  *packet,
 				guchar      *header,
 				int          value);
 
@@ -72,12 +72,34 @@ void         nd_gui_init(void);
 
 
 /**
- * nd_gui_sync - reflect app status in GUI.
+ * nd_gui_sync_menus - reflect app status in GUI menus.
  *
  * This function sets various GUI elements sensitive or insensitive
  * according to the current packet/trace selection.
  */
-void         nd_gui_sync(void);
+void         nd_gui_sync_menus(void);
+
+
+/**
+ * nd_gui_sync_edit_menu - reflect app status in edit menu.
+ */
+void         nd_gui_sync_edit_menu(void);
+
+/**
+ * nd_gui_sync_file_menu - reflect app status in file menu.
+ */
+void         nd_gui_sync_file_menu(void);
+
+/**
+ * nd_gui_sync_go_menu - reflect app status in go menu.
+ */
+void         nd_gui_sync_go_menu(void);
+
+/**
+ * nd_gui_sync_protocol_menu - reflect app status in protocol menu.
+ */
+void         nd_gui_sync_protocol_menu(void);
+
 
 
 /**
@@ -89,8 +111,18 @@ void         nd_gui_sync(void);
  */
 void         nd_gui_show_packet_menu(GdkEventButton *event);
 
-void         nd_gtk_clist_select_all(GtkCList *clist);
-void         nd_gtk_clist_unselect_all(GtkCList *clist);
+
+/**
+ * nd_gui_show_iterator_mode_menu - pops up per-trace iterator mode menu.
+ * @event: mouse event that contains coordinates where to pop up menu.
+ *
+ * This function pops up the packet iteration mode menu when the user
+ * clicks on the button in the trace's tab.
+ */
+void         nd_gui_show_iterator_mode_menu(GdkEventButton *event);
+
+
+
 
 
 /**
@@ -103,14 +135,24 @@ void         nd_gui_num_packets_set(void);
 
 
 /**
- * nd_gui_modified_set - updates GUI to trace's modification status.
+ * nd_gui_set_trace_status - updates GUI to trace's modification status.
  * @trace: trace to sync GUI to.
  *
  * The function adjusts the GUI to reflect the modification status
  * of @trace (at the moment this means that the close button of
  * @trace is displayed either red or green).
  */
-void         nd_gui_modified_set(ND_Trace *trace);
+void         nd_gui_set_trace_status(LND_Trace *trace);
+
+
+/**
+ * nd_gui_iteration_mode_set - updates GUI to trace's iterator mode.
+ * @trace: trace to sync GUI to.
+ *
+ * The function adjusts the GUI to reflect the selected iterator
+ * mode of @trace.
+ */
+void         nd_gui_iterator_mode_set(LND_Trace *trace);
 
 
 /**
@@ -122,6 +164,18 @@ void         nd_gui_modified_set(ND_Trace *trace);
  */
 void         nd_gui_statusbar_set(const char *text);
 
+
+/**
+ * nd_gui_statusbar_set_noclear - sets the status bar content.
+ * @text: new statusbar message.
+ *
+ * The function sets the statusbar content to @text just like
+ * nd_gui_statusbar_set(), but doesn't schedule a timeout to
+ * clear the bar.
+ */
+void         nd_gui_statusbar_set_noclear(const char *text);
+
+
 /**
  * nd_gui_statusbar_clear - clears status bar message.
  * @data: unused.
@@ -138,29 +192,31 @@ gint         nd_gui_statusbar_clear(gpointer data);
 
 /**
  * nd_gui_pbar_reset - initializes/resets the progress bar to a given value.
- * @num_steps: number of steps between 0% and 100%.
+ * @num_total: number of steps between 0% and 100%.
  *
  * The function initializes the progress bar in the lower right
  * part of the main window to @num_steps number of steps.
- * Each call to nd_gui_pbar_inc() will advance the  progress
- * bar by one of these steps.
  */
-void         nd_gui_pbar_reset(int num_steps);
+void         nd_gui_pbar_reset(int num_total);
 
 /**
  * nd_gui_pbar_inc - increments progress bar.
+ * @num_inc: value to add to progress bar.
  *
- * The function increments the progress bar. The amount by which
- * is increased depends on the value passed to nd_gui_pbar_reset().
+ * The function increments the progress bar by @num_inc units. The value
+ * is bounded by the maximum value specified when nd_gui_pbar_reset()
+ * was called, so you cannot pass something "too large" here.
  */
-void         nd_gui_pbar_inc(void);
+void         nd_gui_pbar_inc(int num_inc);
 
 /**
  * nd_gui_pbar_clear - resets progress bar.
- * 
- * The function clears the progress bar in the main window.
+ * @interval: delay in milliseconds before the progress bar is cleared.
+ *
+ * The function clears the progress bar in the main window, after
+ * waiting the given amount of time if specified.
  */
-void         nd_gui_pbar_clear(void);
+void         nd_gui_pbar_clear(int interval);
 
 /**
  * nd_gui_pbar_start_activity - starts activity display in the progress bar.
@@ -178,9 +234,12 @@ void         nd_gui_pbar_start_activity(void);
 void         nd_gui_pbar_stop_activity(void);
 
 
+void         nd_gui_list_freeze(LND_Trace *trace);
+void         nd_gui_list_thaw(LND_Trace *trace);
+
 /**
  * nd_gui_list_incomplete_column_visible - enables/disables display of the completeness column.
- * @clist: list widget to adjust.
+ * @trace: trace whose list widget to adjust.
  * @visible: whether to show or hide the column.
  *
  * The packet lists for each trace can provide an additional column indicating
@@ -188,11 +247,11 @@ void         nd_gui_pbar_stop_activity(void);
  * whether this column is visible or not. @clist is usually obtained from
  * the current trace as trace->list.
  */
-void         nd_gui_list_incomplete_column_visible(GtkWidget *clist, gboolean visible);
+void         nd_gui_list_set_incomplete_column_visible(LND_Trace *trace, gboolean visible);
 
 /**
- * nd_gui_list_incomplete_row_set - toggles a given line's completeness display.
- * @clist: list widget to update.
+ * nd_gui_list_set_row_incomplete - toggles a given line's completeness display.
+ * @trace: trace whose list widget to adjust.
  * @row: which row to update.
  * @incomplete: whether to mark the row as an incomplete packet or not.
  *
@@ -200,41 +259,69 @@ void         nd_gui_list_incomplete_column_visible(GtkWidget *clist, gboolean vi
  * packet. See also nd_gui_list_incomplete_column_visible(). The function
  * does not adjust any internal structures -- only the GUI.
  */
-void         nd_gui_list_incomplete_row_set(GtkWidget *clist, int row, gboolean incomplete);
+void         nd_gui_list_set_row_incomplete(LND_Trace *trace, int row, gboolean incomplete);
+
+/**
+ * nd_gui_list_set_row_filtered - toggles a given line's filter status.
+ * @trace: trace whose list widget to update.
+ * @row: which row to update.
+ * @filtered: whether to mark the row as filtered or not.
+ *
+ */
+void         nd_gui_list_set_row_filtered(LND_Trace *trace, int row, gboolean filtered);
 
 /**
  * nd_gui_list_remove_selected_rows - removes selected rows from list widget.
- * @clist: list widget to update.
+ * @trace: trace whose list widget to update.
  *
  * The function removes the selected rows from @clist. This updates
  * only the widget, no signals are emitted. Use the clist functions
  * for full service.
  */
-void         nd_gui_list_remove_selected_rows(GtkWidget *clist);
+void         nd_gui_list_remove_selected_rows(LND_Trace *trace);
+
 
 /**
  * nd_gui_list_remove_row - removes a single row from list widget.
- * @clist: list widget to update.
+ * @trace: trace whose list widget to update.
  * @index: row number to remove.
  *
- * The function removes the specified row from @clist (counting starts
- * at zero). This updates only the widget, no signals are emitted.
- * Use the clist functions for full service.
+ * The function removes the specified row from @trace's list widget,
+ * (counting starts at zero). This updates only the widget, no
+ * signals are emitted. Use the clist functions for full service.
  */
-void         nd_gui_list_remove_row(GtkWidget *clist, guint index);
+void         nd_gui_list_remove_row(LND_Trace *trace, guint index);
+
+
+/**
+ * nd_gui_list_insert_row - inserts a single row into the list widget.
+ * @packet: packet whose data to insert.
+ * @index: row number of the new line.
+ *
+ * The function inserts the packet's tcpdump data as a new row
+ * into the packet trace's list widget.
+ */
+void         nd_gui_list_insert_row(LND_Packet *packet, int index);
+
+
+/**
+ * nd_gui_list_clear - removes all rows from list widget.
+ * @trace: trace whose list widget to update.
+ *
+ * The function removes all entries from @trace's list widget,
+ * without emitting any signals.
+ */
+void         nd_gui_list_clear(LND_Trace *trace);
+
 
 /**
  * nd_gui_list_update - updates all tcpdump lines.
  * @trace: trace to update.
- * @find_context: whether to find context for packets.
  *
- * The function refreshes the tcpdump output for @trace. If @find_context
- * is %TRUE, each packet's tcpdump output is updated to reflect
- * the context of the packet in the trace. This update depends on
- * what the protocols do with the line string in their update_tcpdump_line()
- * implementation. Also, the completeness column is updated.
+ * The function refreshes the tcpdump output for @trace.
  */
-void         nd_gui_list_update(ND_Trace *trace, gboolean find_context);
+void         nd_gui_list_update(LND_Trace *trace);
+
 
 /**
  * nd_gui_list_update_packet - updates tcpdump output for packet.
@@ -244,7 +331,8 @@ void         nd_gui_list_update(ND_Trace *trace, gboolean find_context);
  * is sent anew to the tcpdump process, then the text is updated.
  * Context is always looked up. The completeness column is updated as well.
  */
-void         nd_gui_list_update_packet(const ND_Packet *packet);
+void         nd_gui_list_update_packet(const LND_Packet *packet);
+
 
 /**
  * nd_gui_list_update_packet_at_index - faster version of nd_gui_list_update_packet().
@@ -254,7 +342,52 @@ void         nd_gui_list_update_packet(const ND_Packet *packet);
  * If you know the index of @packet in its trace, use this function
  * instead of nd_gui_list_update_packet().
  */
-void         nd_gui_list_update_packet_at_index(const ND_Packet *packet, int index);
+void         nd_gui_list_update_packet_at_index(const LND_Packet *packet, int index);
+
+
+/**
+ * nd_gui_list_select_packet - selects a given row in the list widget.
+ * @trace: trace to update.
+ * @index: row number to select.
+ *
+ * The function selects row @index in @trace's list widget. A signal
+ * is emitted.
+ */
+void         nd_gui_list_select_packet(LND_Trace *trace, guint index);
+
+
+/**
+ * nd_gui_list_unselect_packet - unselects a given row in the list widget.
+ * @trace: trace to update.
+ * @index: row number to unselect.
+ *
+ * The function unselects row @index in @trace's list widget. A signal
+ * is emitted.
+ */
+void         nd_gui_list_unselect_packet(LND_Trace *trace, guint index);
+
+
+/**
+ * nd_gui_list_unselect_all - unselects all packets in list widget.
+ * @trace: trace to update.
+ * @emit_signal: whether to emit unselect signals or not.
+ *
+ * The function unselects all rows in @trace's list widget. A signal
+ * is emitted depending on @emit_signal.
+ */
+void         nd_gui_list_unselect_all(LND_Trace *trace, gboolean emit_signal);
+
+
+/**
+ * nd_gui_list_select_all - selects all packets in list widget.
+ * @trace: trace to update.
+ * @emit_signal: whether to emit select signals or not.
+ *
+ * The function elects all rows in @trace's list widget. A signal
+ * is emitted depending on @block_signal.
+ */
+void         nd_gui_list_select_all(LND_Trace *trace, gboolean emit_signal);
+
 
 /**
  * nd_gui_list_update_packet_state - updates tcpdump output line directly.
@@ -264,7 +397,7 @@ void         nd_gui_list_update_packet_at_index(const ND_Packet *packet, int ind
  * iterates over all protocol in the packet, calling their
  * update_tcpdump_line() implementations.
  */
-void         nd_gui_list_update_packet_state(const ND_Packet *packet);
+void         nd_gui_list_update_packet_state(const LND_Packet *packet);
 
 /**
  * nd_gui_list_update_packet_state_at_index - faster version of nd_gui_list_update_packet_state()
@@ -274,17 +407,18 @@ void         nd_gui_list_update_packet_state(const ND_Packet *packet);
  * If you know the index of @packet in its trace, use this function
  * instead of nd_gui_list_update_packet_state().
  */
-void         nd_gui_list_update_packet_state_at_index(const ND_Packet *packet, int index);
+void         nd_gui_list_update_packet_state_at_index(const LND_Packet *packet, int index);
+
 
 /**
- * nd_gui_windowtitle_set - sets main window title.
+ * nd_gui_set_windowtitle - sets main window title.
  * @filename: new (canonical) filename to display in window title.
  *
  * The function displays the given file name in the window title.
  * Depending on the current preferences, the canonical filename
  * or the filename only will be shown.
 */
-void         nd_gui_windowtitle_set(const char *filename);
+void         nd_gui_set_windowtitle(const char *filename);
 
 
 /**
@@ -311,7 +445,7 @@ void         nd_gui_timestamp_hide(void);
  * Protocol plugins can provide a menu for any features they provide.
  * This function takes care of hooking those menus into the main window.
  */
-void         nd_gui_proto_menu_register(ND_Protocol *proto);
+void         nd_gui_proto_menu_register(LND_Protocol *proto);
 
 /**
  * nd_gui_trace_add - adds a trace to the GUI.
@@ -322,7 +456,7 @@ void         nd_gui_proto_menu_register(ND_Protocol *proto);
  * is called automatically through the callback that gets activated
  * when the trace is added.
  */
-void         nd_gui_trace_add(ND_Trace *trace);
+void         nd_gui_trace_add(LND_Trace *trace);
 
 /**
  * nd_gui_trace_remove - removes a trace from the GUI.
@@ -331,7 +465,7 @@ void         nd_gui_trace_add(ND_Trace *trace);
  * The function removes @trace from the GUI. No other internal
  * data structures are touched.
  */
-void         nd_gui_trace_remove(ND_Trace *trace);
+void         nd_gui_trace_remove(LND_Trace *trace);
 
 
 /**
@@ -341,17 +475,17 @@ void         nd_gui_trace_remove(ND_Trace *trace);
  * The function creates a new GTK notebook tab for @trace
  * and hooks them into the given trace.
  */
-void         nd_gui_trace_new_tab(ND_Trace *trace);
+void         nd_gui_trace_new_tab(LND_Trace *trace);
 
 /**
- * nd_gui_trace_name_set - syncs the tab label of a trace to its filename
+ * nd_gui_trace_set_name - syncs the tab label of a trace to its filename
  * @trace: trace for which tab is updated.
  * 
  * The function updates the notebook tab label of @trace
  * to its current name and whether or not the canonical
  * or the local filename is displayed.
  */
-void         nd_gui_trace_name_set(ND_Trace *trace);
+void         nd_gui_trace_set_name(LND_Trace *trace);
 
 
 /**
@@ -389,13 +523,13 @@ GtkWidget   *nd_gui_create_menu(ND_MenuData *data);
  *
  * The function creates a GUI table based upon the specification of
  * a protocol. The result depends on the statically initialized array
- * which the trace->fields pointer points to. Its last array entry must
- * contain %NULL values.
+ * which the ND_Protocol's 'fields' pointer points to. Its last array
+ * entry must contain a %NULL value.
  *
  * Returns: created table, a GtkTable.
  */
-GtkWidget   *nd_gui_proto_table_create(ND_Trace *trace,
-				       ND_ProtoInfo *pinf);
+GtkWidget   *nd_gui_proto_table_create(LND_Trace *trace,
+				       LND_ProtoInfo *pinf);
 
 /**
  * nd_gui_proto_table_clear - reset optional fields in protocol header table.
@@ -407,8 +541,8 @@ GtkWidget   *nd_gui_proto_table_create(ND_Trace *trace,
  * options etc. To remove any previously added optional buttons,
  * call this function.
  */
-void         nd_gui_proto_table_clear(ND_Trace *trace,
-				      ND_ProtoInfo *pinf);
+void         nd_gui_proto_table_clear(LND_Trace *trace,
+				      LND_ProtoInfo *pinf);
 
 /**
  * nd_gui_proto_table_add - adds an optional field to a protocol header table.
@@ -424,8 +558,8 @@ void         nd_gui_proto_table_clear(ND_Trace *trace,
  * what data needs to be passed here. When @is_error is %TRUE, the button
  * is changed in color accordingly.
  */
-void         nd_gui_proto_table_add(ND_Trace *trace,
-				    ND_ProtoInfo *pinf,
+void         nd_gui_proto_table_add(LND_Trace *trace,
+				    LND_ProtoInfo *pinf,
 				    ND_ProtoField *field,
 				    void *data,
 				    gboolean is_error);
@@ -440,7 +574,7 @@ void         nd_gui_proto_table_add(ND_Trace *trace,
  * table for the protocol instance specified in @pi. Match this up
  * with nd_gui_proto_table_unblock_events()!
  */
-void         nd_gui_proto_table_block_events(ND_Trace *trace, ND_ProtoInfo *pi);
+void         nd_gui_proto_table_block_events(LND_Trace *trace, LND_ProtoInfo *pi);
 
 /**
  * nd_gui_proto_table_unblock_events - unblocks event propagation.
@@ -451,7 +585,7 @@ void         nd_gui_proto_table_block_events(ND_Trace *trace, ND_ProtoInfo *pi);
  * table for the protocol instance specified in @pi. Use this after
  * blocking the events with nd_gui_proto_table_block_events().
  */
-void         nd_gui_proto_table_unblock_events(ND_Trace *trace, ND_ProtoInfo *pi);
+void         nd_gui_proto_table_unblock_events(LND_Trace *trace, LND_ProtoInfo *pi);
 
 
 /**
@@ -482,4 +616,7 @@ void         nd_gui_del_monowidth_widget(GtkWidget *widget);
  */
 void         nd_gui_update_monowidth_widgets(void);
 
+void         nd_gui_update_view_indicator(void);
+void         nd_gui_update_area_indicator(void);
+
 #endif
