@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -26,17 +26,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __nd_macros_h
 
 #include <stdlib.h>
-#include <netdude/nd_trace_registry.h>
-
-#define	TV_SUB(a,b,c)	{ \
-	(c)->tv_sec = (a)->tv_sec - (b)->tv_sec; \
-	if ((a)->tv_usec < (b)->tv_usec) { \
-		(c)->tv_sec -= 1;		/* need to borrow */ \
-		(c)->tv_usec = ((a)->tv_usec + 1000000) - (b)->tv_usec; \
-	} else { \
-		(c)->tv_usec = (a)->tv_usec - (b)->tv_usec; \
-	} \
-}
 
 /**
  * return_if_no_current_trace - current trace safety check.
@@ -62,14 +51,36 @@ do { tr = nd_trace_registry_get_current(); D_ASSERT_PTR(tr); if (!tr) return (va
 
 
 /**
- * TOUCH - suppresses warnings.
- * @x: unused variable to be silenced.
+ * ND_GTK_GET - gtk_object_get_data wrapper.
+ * @res: result object
+ * @widget: object to query
+ * @key: key name of data to look up
  * 
- * The macro's purpose is to touch a variable and thus
- * shut up compiler warnings when there are unused
- * parameters in the code.
+ * The macro is a wrapper for gtk_object_get_data() that
+ * also asserts the existance of the pointer on return,
+ * pointing out where in the program an invalid key was
+ * used.
  */
-#define TOUCH(x)  { x = 0; }
+#define ND_GTK_GET(res, widget, key) \
+do { \
+  res = gtk_object_get_data(GTK_OBJECT(widget), key); \
+  D_ASSERT_PTR(res); \
+} while (0)
+
+/**
+ * ND_GTK_SET - gtk_object_set_data wrapper.
+ * @obj: object
+ * @widget: widget to set object in
+ * @key: key name of data
+ * 
+ * The macro is a wrapper for gtk_object_set_data(),
+ * provided for consistency with ND_GTK_GET().
+ */
+#define ND_GTK_SET(obj, widget, key) \
+do { \
+  D_ASSERT_PTR(obj); \
+  gtk_object_set_data(GTK_OBJECT(widget), key, obj); \
+} while (0)
 
 #endif
      
