@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -26,7 +26,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __nd_plugin_h
 
 #include <ltdl.h>
-#include <netdude/nd_trace.h>
+#include <nd_trace.h>
 
 /* Netdude plugins are dynamically loaded modules that can act as filters
  * on packets of a tracefile, or can basically do anything you want them
@@ -35,19 +35,18 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
  * Possible applications are anonymizers, checksummers etc. 
  */
-typedef struct nd_plugin
-{
-  const char *(*name) (void);
-  const char *(*description) (void);
-  const char *(*author) (void);
-  const char *(*version) (void);
+typedef struct nd_plugin ND_Plugin;
 
-  int         (*run) (ND_Trace *trace);
 
-  char        *filename;
-  lt_dlhandle  lt;
-
-} ND_Plugin;
+/**
+ * ND_PluginFunc - signature of plugin iteration callbacks.
+ * @plugin: iterated plugin.
+ * @user_data: arbitrary user data.
+ *
+ * This is the signature of functions that can be passed to
+ * nd_plugin_foreach().
+ */
+typedef void (*ND_PluginFunc)(ND_Plugin *plugin, void *user_data);
 
 
 /**
@@ -67,6 +66,17 @@ void          nd_plugin_init(void);
  */
 void          nd_plugin_run(ND_Plugin *plugin);
 
+/**
+ * nd_plugin_get_name - returns plugin name.
+ * @plugin: plugin to query.
+ *
+ * The function returns a pointer to statically allocated memory
+ * containing the plugin's name.
+ *
+ * Returns: plugin name.
+ */
+const char   *nd_plugin_get_name(ND_Plugin *plugin);
+
 /**
  * nd_plugin_get_description - returns plugin description string.
  * @plugin: plugin to query.
@@ -89,6 +99,17 @@ const char   *nd_plugin_get_description(ND_Plugin *plugin);
  */
 const char   *nd_plugin_get_author(ND_Plugin *plugin);
 
+/**
+ * nd_plugin_get_version - returns plugin version.
+ * @plugin: plugin to query.
+ *
+ * The function returns a pointer to statically allocated memory
+ * containing the plugin's version string.
+ *
+ * Returns: version string.
+ */
+const char   *nd_plugin_get_version(ND_Plugin *plugin);
+
 /**
  * nd_plugin_show_about - shows About dialog for plugin.
  * @plugin: plugin whose About info is shown.
@@ -98,4 +119,16 @@ const char   *nd_plugin_get_author(ND_Plugin *plugin);
  */
 void          nd_plugin_show_about(ND_Plugin *plugin);
 
+
+/**
+ * nd_plugin_foreach - plugin iteration.
+ * @callback: callback to call for each plugin.
+ * @user_data: arbitrary user data passed through to @callback.
+ *
+ * The function iterates over the registered plugins and applies
+ * a callback function to each of them.
+ */
+void          nd_plugin_foreach(ND_PluginFunc callback,
+				void *user_data);
+
 #endif
