@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2007 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -25,6 +25,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __nd_timestamp_h
 #define __nd_timestamp_h
 
-#define LAST_UPDATE "Sun Jun 24 13:47:32 PDT 2007"
+#define LAST_UPDATE "Mon Mar 15 22:50:39 PDT 2010"
 
 #endif
