@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2007 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -414,16 +414,17 @@ nd_trace_set_current_proto(LND_Trace *trace,
   GtkNotebook *notebook;
   LND_Packet *packet = NULL;
   int num;
-
+  LND_Protocol *pcap_proto = libnd_proto_registry_find(LND_PROTO_LAYER_LINK, 0xa1b2c3d4);
+  
   if (! trace_gui || ! trace_gui->cur_packet || ! pi ||
       ! (packet = trace_gui->cur_packet) ||
-      ! libnd_packet_has_proto_nested(packet, pi->proto, pi->nesting))
+      (pi->proto != pcap_proto && ! libnd_packet_has_proto_nested(packet, pi->proto, pi->nesting)))
     {
       if (gui_update)
 	nd_gui_statusbar_clear(NULL);
       return;
     }
-  
+
   D(("Setting current proto to %s/%i\n", pi->proto->name, pi->nesting));
   
   if (!trace_gui->cur_pi)
@@ -432,7 +433,7 @@ nd_trace_set_current_proto(LND_Trace *trace,
       if (!trace_gui->cur_pi)
 	return;
     }
-  
+
   *trace_gui->cur_pi = *pi;
   
   if (packet)
@@ -443,7 +444,6 @@ nd_trace_set_current_proto(LND_Trace *trace,
   
   if (gui_update)
     {
-      LND_Protocol *pcap_proto = libnd_proto_registry_find(LND_PROTO_LAYER_LINK, 0xa1b2c3d4);
       LND_ProtoInfo *pinf;
       ND_ProtoInfo  *pinf_gui;
       char buf[512];
@@ -464,8 +464,31 @@ nd_trace_set_current_proto(LND_Trace *trace,
       gtk_signal_handler_unblock_by_data(GTK_OBJECT(notebook), notebook);
 
       /* Report the protocol's size in bytes in the statusbar if feasible. */
-      if (! pi->proto || (pcap_proto && pi->proto == pcap_proto))
+      if (! pi->proto)
 	nd_gui_statusbar_clear(NULL);
+      else if (pi->proto == pcap_proto)
+	{
+	  GList *l;
+	  LND_ProtoData *pd;
+
+	  for (l = packet->pd; l; l = g_list_next(l))
+	    {
+	      int delta;
+
+	      if (g_list_next(l))
+		continue;
+
+	      pd = (LND_ProtoData *) l->data;
+	      buf[0] = '\0';
+	      delta = packet->ph.len - (pd->data_end - packet->data);
+	      
+	      if (delta > 0)
+		g_snprintf(buf, 512, _("%d bytes of packet data not used by protocols."),
+			   delta);
+	      
+	      nd_gui_statusbar_set_noclear(buf);		  
+	    }
+	}
       else
 	{
 	  /* Find out the index of the given protocol instance, and use it
